@@ -145,7 +145,7 @@ class TaskLogger:
             solver=solver.solver if solver else None,
             tags=tags,
             solver_args=solver.args if solver else None,
-            model=f"{ModelName(model).api}/{model.api.canonical_name()}",
+            model=f"{ModelName(model).api}/{model.name}",
             model_generate_config=model.config,
             model_base_url=model.api.base_url,
             model_roles=model_roles_to_model_roles_config(model_roles),
@@ -273,11 +273,7 @@ class TaskLogger:
         return log
 
 
-async def log_start(
-    logger: TaskLogger,
-    plan: Plan,
-    config: GenerateConfig,
-) -> None:
+def plan_to_eval_plan(plan: Plan, config: GenerateConfig) -> EvalPlan:
     def eval_plan_step(solver: Solver) -> EvalPlanStep:
         return EvalPlanStep(
             solver=registry_log_name(solver), params=registry_params(solver)
@@ -291,7 +287,15 @@ async def log_start(
     )
     if plan.finish:
         eval_plan.steps.append(eval_plan_step(plan.finish))
+    return eval_plan
 
+
+async def log_start(
+    logger: TaskLogger,
+    plan: Plan,
+    config: GenerateConfig,
+) -> None:
+    eval_plan = plan_to_eval_plan(plan, config)
     await logger.log_start(eval_plan)
 
 
