@@ -31,6 +31,7 @@ from inspect_ai._util.dateutil import iso_now
 from inspect_ai._util.error import exception_message
 from inspect_ai._util.exception import TerminateSampleError
 from inspect_ai._util.json import to_json_str_safe
+from inspect_ai._util.notgiven import NOT_GIVEN
 from inspect_ai._util.registry import (
     is_registry_object,
     registry_log_name,
@@ -68,7 +69,6 @@ from inspect_ai.log._transcript import (
     transcript,
 )
 from inspect_ai.model import (
-    CachePolicy,
     GenerateConfig,
     GenerateConfigArgs,
     Model,
@@ -148,6 +148,23 @@ class TaskRunOptions:
     kwargs: GenerateConfigArgs = field(default_factory=lambda: GenerateConfigArgs())
 
 
+def resolve_plan(task: Task, solver: Solver | None) -> Plan:
+    # resolve the plan (unroll chains)
+    solver = solver or task.solver
+    if isinstance(solver, Plan):
+        plan = solver
+    elif isinstance(solver, Chain):
+        plan = Plan(list(solver), cleanup=task.cleanup, internal=True)
+    else:
+        plan = Plan(unroll(solver), cleanup=task.cleanup, internal=True)
+
+    # add setup solver(s) if specified
+    if task.setup:
+        plan.steps = unroll(task.setup) + plan.steps
+
+    return plan
+
+
 async def task_run(options: TaskRunOptions) -> EvalLog:
     from inspect_ai.hooks._hooks import (
         emit_task_end,
@@ -212,16 +229,7 @@ async def task_run(options: TaskRunOptions) -> EvalLog:
 
     # resolve the plan (unroll chains)
     solver = solver or task.solver
-    if isinstance(solver, Plan):
-        plan = solver
-    elif isinstance(solver, Chain):
-        plan = Plan(list(solver), cleanup=task.cleanup, internal=True)
-    else:
-        plan = Plan(unroll(solver), cleanup=task.cleanup, internal=True)
-
-    # add setup solver(s) if specified
-    if task.setup:
-        plan.steps = unroll(task.setup) + plan.steps
+    plan = resolve_plan(task, solver)
 
     # resolve the scorer
     score = score and task.scorer is not None
@@ -278,14 +286,13 @@ async def task_run(options: TaskRunOptions) -> EvalLog:
                 async def generate(
                     state: TaskState,
                     tool_calls: Literal["loop", "single", "none"] = "loop",
-                    cache: bool | CachePolicy = False,
                     **kwargs: Unpack[GenerateConfigArgs],
                 ) -> TaskState:
                     return await task_generate(
                         model=model,
                         state=state,
                         tool_calls=tool_calls,
-                        cache=cache,
+                        cache=kwargs.get("cache", False) or NOT_GIVEN,
                         config=generate_config.merge(kwargs),
                     )
 
@@ -532,6 +539,7 @@ def update_metrics_display_fn(
                                 name=metric.name,
                                 value=metric.value,
                                 reducer=score.reducer,
+                                params=metric.params,
                             )
                         )
                 update_fn(task_metrics)
