@@ -8,6 +8,7 @@ from typing import Any, Protocol
 import anyio
 import uvicorn
 from fastapi import FastAPI, HTTPException, Query, Request, Response
+from fastapi.responses import StreamingResponse
 from pydantic_core import to_jsonable_python
 from starlette.middleware.base import BaseHTTPMiddleware, RequestResponseEndpoint
 from starlette.responses import JSONResponse
@@ -27,7 +28,6 @@ from inspect_ai._util.file import filesystem
 from inspect_ai._view import notify
 from inspect_ai._view.common import (
     delete_log,
-    get_log_bytes,
     get_log_dir,
     get_log_file,
     get_log_files,
@@ -35,6 +35,7 @@ from inspect_ai._view.common import (
     get_logs,
     normalize_uri,
     parse_log_token,
+    stream_log_bytes,
 )
 from inspect_ai.log._file import read_eval_log_headers_async
 from inspect_ai.log._recorders.buffer import sample_buffer
@@ -139,8 +140,8 @@ def view_server_app(
     ) -> Response:
         file = normalize_uri(log)
         await _validate_read(request, file)
-        response = await get_log_bytes(await _map_file(request, file), start, end)
-        return Response(
+        response = await stream_log_bytes(await _map_file(request, file), start, end)
+        return StreamingResponse(
             content=response,
             headers={"Content-Length": str(end - start + 1)},
             media_type="application/octet-stream",
@@ -174,12 +175,16 @@ def view_server_app(
         if client_etag is not None:
             mtime, file_count = parse_log_token(client_etag)
         log_files_response: dict[str, Any] = await get_log_files(
-            log_dir,
+            await _map_file(request, log_dir),
             recursive=recursive,
             fs_options=fs_options,
             mtime=mtime,
             file_count=file_count,
         )
+        log_files_response["files"] = [
+            {**file, "name": await _unmap_file(request, file["name"])}
+            for file in log_files_response["files"]
+        ]
         return InspectJsonResponse(content=log_files_response)
 
     @app.get("/logs")
@@ -204,16 +209,25 @@ def view_server_app(
 
     @app.get("/eval-set")
     async def eval_set(
-        request: Request, log_dir: str = Query(None, alias="dir")
+        request: Request,
+        log_dir: str = Query(None, alias="log_dir"),
+        sub_dir: str = Query(None, alias="dir"),
     ) -> Response:
-        if log_dir:
-            log_dir = default_dir + "/" + log_dir.lstrip("/")
-        elif log_dir is None:
-            log_dir = default_dir
-        await _validate_list(request, log_dir)
+        # resolve the eval-set directory (using the log_dir and dir params)
+        base_dir = log_dir if log_dir else default_dir
+        if sub_dir and base_dir:
+            eval_set_dir = base_dir + "/" + sub_dir.lstrip("/")
+        elif sub_dir:
+            eval_set_dir = sub_dir.lstrip("/")
+        else:
+            eval_set_dir = base_dir
 
+        # validate that the directory can be listed
+        await _validate_list(request, eval_set_dir)
+
+        # return the eval set info for this directory
         eval_set = read_eval_set_info(
-            await _map_file(request, log_dir), fs_options=fs_options
+            await _map_file(request, eval_set_dir), fs_options=fs_options
         )
         return InspectJsonResponse(
             content=eval_set.model_dump(exclude_none=True) if eval_set else None
