@@ -1,9 +1,9 @@
-import { LogFile, LogOverview } from "../../client/api/types";
+import { LogHandle, LogPreview } from "../../client/api/types";
 
 export interface LogItem {
   id: string;
   name: string;
-  url: string;
+  url?: string;
 }
 
 export interface FolderLogItem extends LogItem {
@@ -13,6 +13,11 @@ export interface FolderLogItem extends LogItem {
 
 export interface FileLogItem extends LogItem {
   type: "file";
-  logFile: LogFile;
-  logOverview?: LogOverview;
+  log: LogHandle;
+  logPreview?: LogPreview;
+}
+
+export interface PendingTaskItem extends LogItem {
+  type: "pending-task";
+  model: string;
 }
