@@ -1,7 +1,7 @@
 import { useCallback } from "react";
 import { useNavigate, useParams } from "react-router-dom";
 import { useStore } from "../../state/store";
-import { logUrl, logUrlRaw } from "./url";
+import { logsUrl, logsUrlRaw } from "./url";
 
 export const useLogNavigation = () => {
   const navigate = useNavigate();
@@ -14,11 +14,11 @@ export const useLogNavigation = () => {
       // Only update URL if we have a loaded log
       if (loadedLog && logPath) {
         // We already have the logPath from params, just navigate to the tab
-        const url = logUrlRaw(logPath, tabId);
+        const url = logsUrlRaw(logPath, tabId);
         navigate(url);
       } else if (loadedLog) {
         // Fallback to constructing the path if needed
-        const url = logUrl(loadedLog, logDir, tabId);
+        const url = logsUrl(loadedLog, logDir, tabId);
         navigate(url);
       }
     },
