@@ -1,5 +1,5 @@
 import { useMemo } from "react";
-import { useParams } from "react-router-dom";
+import { useLocation, useParams } from "react-router-dom";
 import {
   kSampleMessagesTabId,
   kSampleTabIds,
@@ -45,6 +45,42 @@ export const useDecodedParams = <
   return decodedParams;
 };
 
+export interface LogOrSampleRouteParams {
+  logPath?: string;
+  id?: string;
+  epoch?: string;
+  sampleTabId?: string;
+  tabId?: string;
+  uuid: string | undefined;
+}
+
+export const useLogOrSampleRouteParams = (): LogOrSampleRouteParams => {
+  const location = useLocation();
+
+  const logParams = useLogRouteParams();
+  const sampleParams = useSamplesRouteParams();
+
+  if (location.pathname.startsWith("/samples/")) {
+    return {
+      logPath: sampleParams.samplesPath,
+      id: sampleParams.sampleId,
+      epoch: sampleParams.epoch,
+      sampleTabId: sampleParams.tabId,
+      tabId: undefined,
+      uuid: undefined,
+    };
+  } else {
+    return {
+      logPath: logParams.logPath,
+      id: logParams.sampleId,
+      epoch: logParams.epoch,
+      tabId: logParams.tabId,
+      sampleTabId: logParams.sampleTabId,
+      uuid: logParams.sampleUuid,
+    };
+  }
+};
+
 /**
  * Hook that parses log route parameters from the splat route.
  * Handles nested paths properly by parsing the full path after /logs/
@@ -200,8 +236,46 @@ export const useLogRouteParams = () => {
   }, [params]);
 };
 
+/**
+ * Hook that parses samples route parameters from the splat route.
+ * Handles nested paths properly by parsing the full path after /samples/
+ * Also handles sample detail routes: /samples/path/to/file.eval/sample/id/epoch
+ */
+export const useSamplesRouteParams = () => {
+  const params = useParams<{
+    "*": string;
+  }>();
+
+  return useMemo(() => {
+    const splatPath = params["*"] || "";
+
+    const sampleMatch = splatPath.match(
+      /^(.+?)\/sample\/([^/]+)\/([^/]+)(?:\/([^/]+))?\/?$/,
+    );
+
+    if (sampleMatch) {
+      const [, logPath, sampleId, epoch, tabId] = sampleMatch;
+      return {
+        samplesPath: decodeUrlParam(logPath),
+        sampleId: decodeUrlParam(sampleId),
+        epoch: decodeUrlParam(epoch),
+        tabId: tabId ? decodeUrlParam(tabId) : undefined,
+      };
+    }
+
+    // Otherwise it's just a folder path
+    return {
+      samplesPath: splatPath ? decodeUrlParam(splatPath) : undefined,
+      sampleId: undefined,
+      epoch: undefined,
+      tabId: undefined,
+    };
+  }, [params]);
+};
+
 export const kLogsRoutUrlPattern = "/logs";
 export const kLogRouteUrlPattern = "/logs/*";
+export const kSamplesRouteUrlPattern = "/samples";
 export const kSampleRouteUrlPattern =
   "/logs/*/samples/sample/:sampleId/:epoch?/:sampleTabId?";
 export const kSampleUuidRouteUrlPattern =
@@ -213,13 +287,36 @@ export const baseUrl = (
   sampleEpoch?: string | number,
 ) => {
   if (sampleId !== undefined && sampleEpoch !== undefined) {
-    return sampleUrl(logPath, sampleId, sampleEpoch);
+    return logSamplesUrl(logPath, sampleId, sampleEpoch);
   } else {
-    return logUrl(logPath);
+    return logsUrl(logPath);
   }
 };
 
-export const sampleUrl = (
+export type SampleUrlBuilder = (
+  logPath: string,
+  sampleId?: string | number,
+  sampleEpoch?: string | number,
+  sampleTabId?: string,
+) => string;
+
+export const useSampleUrlBuilder = () => {
+  const location = useLocation();
+  return (
+    logPath: string,
+    sampleId?: string | number,
+    sampleEpoch?: string | number,
+    sampleTabId?: string,
+  ) => {
+    if (sampleId && sampleEpoch && location.pathname.startsWith("/samples/")) {
+      return samplesSampleUrl(logPath, sampleId, sampleEpoch, sampleTabId);
+    } else {
+      return logSamplesUrl(logPath, sampleId, sampleEpoch, sampleTabId);
+    }
+  };
+};
+
+export const logSamplesUrl = (
   logPath: string,
   sampleId?: string | number,
   sampleEpoch?: string | number,
@@ -239,19 +336,31 @@ export const sampleUrl = (
   }
 };
 
+export const samplesSampleUrl = (
+  logPath: string,
+  sampleId: string | number,
+  epoch: string | number,
+  sampleTabId?: string,
+) => {
+  const decodedLogPath = decodeUrlParam(logPath) || logPath;
+  return encodePathParts(
+    `/samples/${decodedLogPath}/sample/${sampleId}/${epoch}/${sampleTabId || ""}`,
+  );
+};
+
 export const sampleEventUrl = (
+  builder: SampleUrlBuilder,
   eventId: string,
   logPath: string,
   sampleId?: string | number,
   sampleEpoch?: string | number,
 ) => {
-  const baseUrl = sampleUrl(
+  const baseUrl = builder(
     logPath,
     sampleId,
     sampleEpoch,
     kSampleTranscriptTabId,
   );
-
   return `${baseUrl}?event=${eventId}`;
 };
 
@@ -262,21 +371,23 @@ export const useSampleMessageUrl = (
 ) => {
   const {
     logPath: urlLogPath,
-    sampleId: urlSampleId,
+    id: urlSampleId,
     epoch: urlEpoch,
-  } = useLogRouteParams();
+  } = useLogOrSampleRouteParams();
+  const builder = useSampleUrlBuilder();
 
   const log_file = useStore((state) => state.logs.selectedLogFile);
   const log_dir = useStore((state) => state.logs.logDir);
 
   let targetLogPath = urlLogPath;
   if (!targetLogPath && log_file) {
-    targetLogPath = makeLogPath(log_file, log_dir);
+    targetLogPath = makeLogsPath(log_file, log_dir);
   }
 
   const messageUrl = useMemo(() => {
     return messageId && targetLogPath
       ? sampleMessageUrl(
+          builder,
           messageId,
           targetLogPath,
           sampleId || urlSampleId,
@@ -294,21 +405,23 @@ export const useSampleEventUrl = (
 ) => {
   const {
     logPath: urlLogPath,
-    sampleId: urlSampleId,
+    id: urlSampleId,
     epoch: urlEpoch,
-  } = useLogRouteParams();
+  } = useLogOrSampleRouteParams();
+  const builder = useSampleUrlBuilder();
 
   const log_file = useStore((state) => state.logs.selectedLogFile);
   const log_dir = useStore((state) => state.logs.logDir);
 
   let targetLogPath = urlLogPath;
   if (!targetLogPath && log_file) {
-    targetLogPath = makeLogPath(log_file, log_dir);
+    targetLogPath = makeLogsPath(log_file, log_dir);
   }
 
   const eventUrl = useMemo(() => {
     return targetLogPath
       ? sampleEventUrl(
+          builder,
           eventId,
           targetLogPath,
           sampleId || urlSampleId,
@@ -320,31 +433,32 @@ export const useSampleEventUrl = (
 };
 
 export const sampleMessageUrl = (
+  builder: SampleUrlBuilder,
   messageId: string,
   logPath: string,
   sampleId?: string | number,
   sampleEpoch?: string | number,
 ) => {
-  const baseUrl = sampleUrl(
-    logPath,
-    sampleId,
-    sampleEpoch,
-    kSampleMessagesTabId,
-  );
-
+  const baseUrl = builder(logPath, sampleId, sampleEpoch, kSampleMessagesTabId);
   return `${baseUrl}?message=${messageId}`;
 };
 
-export const logUrl = (log_file: string, log_dir?: string, tabId?: string) => {
-  return logUrlRaw(makeLogPath(log_file, log_dir), tabId);
+export const samplesUrl = (log_file: string, log_dir?: string) => {
+  const path = makeLogsPath(log_file, log_dir);
+  const decodedLogSegment = decodeUrlParam(path) || path;
+  return encodePathParts(`/samples/${decodedLogSegment}`);
 };
 
-export const makeLogPath = (log_file: string, log_dir?: string) => {
+export const logsUrl = (log_file: string, log_dir?: string, tabId?: string) => {
+  return logsUrlRaw(makeLogsPath(log_file, log_dir), tabId);
+};
+
+export const makeLogsPath = (log_file: string, log_dir?: string) => {
   const pathSegment = directoryRelativeUrl(log_file, log_dir);
   return pathSegment;
 };
 
-export const logUrlRaw = (log_segment: string, tabId?: string) => {
+export const logsUrlRaw = (log_segment: string, tabId?: string) => {
   // Ensure log_segment is decoded before encoding for URL construction
   const decodedLogSegment = decodeUrlParam(log_segment) || log_segment;
 
