@@ -8,16 +8,16 @@ import {
   useRef,
 } from "react";
 
-import { EventNode } from "../types";
+import { EventNode, kTranscriptOutlineCollapseScope } from "../types";
 
 import clsx from "clsx";
 import { Virtuoso, VirtuosoHandle } from "react-virtuoso";
 import { useScrollTrack, useVirtuosoState } from "../../../../state/scrolling";
 import { useStore } from "../../../../state/store";
-import { flatTree } from "../transform/treeify";
 
 import { useSampleDetailNavigation } from "../../../routing/sampleNavigation";
 import { kSandboxSignalName } from "../transform/fixups";
+import { flatTree } from "../transform/flatten";
 import { OutlineRow } from "./OutlineRow";
 import styles from "./TranscriptOutline.module.css";
 import {
@@ -29,7 +29,6 @@ import {
   removeStepSpanNameVisitor,
 } from "./tree-visitors";
 
-const kCollapseScope = "transcript-outline";
 const kFramesToStabilize = 10;
 
 interface TranscriptOutlineProps {
@@ -136,8 +135,9 @@ export const TranscriptOutline: FC<TranscriptOutlineProps> = ({
     // flattten the event tree
     const nodeList = flatTree(
       eventNodes,
-      (collapsedEvents ? collapsedEvents[kCollapseScope] : undefined) ||
-        defaultCollapsedIds,
+      (collapsedEvents
+        ? collapsedEvents[kTranscriptOutlineCollapseScope]
+        : undefined) || defaultCollapsedIds,
       [
         // Strip specific nodes
         removeNodeVisitor("logger"),
@@ -205,7 +205,7 @@ export const TranscriptOutline: FC<TranscriptOutlineProps> = ({
   useEffect(() => {
     // Only initialize collapsedEvents if it's empty
     if (!collapsedEvents && Object.keys(defaultCollapsedIds).length > 0) {
-      setCollapsedEvents(kCollapseScope, defaultCollapsedIds);
+      setCollapsedEvents(kTranscriptOutlineCollapseScope, defaultCollapsedIds);
     }
   }, [defaultCollapsedIds, collapsedEvents, setCollapsedEvents]);
 
@@ -222,7 +222,7 @@ export const TranscriptOutline: FC<TranscriptOutlineProps> = ({
       } else {
         return (
           <OutlineRow
-            collapseScope={kCollapseScope}
+            collapseScope={kTranscriptOutlineCollapseScope}
             node={node}
             key={node.id}
             running={running && index === outlineNodeList.length - 1}
