@@ -1,8 +1,11 @@
 from ._agent import Agent, AgentState, agent, agent_with, is_agent
 from ._as_solver import as_solver
 from ._as_tool import as_tool
-from ._bridge.bridge import bridge
-from ._filter import MessageFilter, last_message, remove_tools
+from ._bridge.bridge import agent_bridge, bridge
+from ._bridge.sandbox.bridge import sandbox_agent_bridge
+from ._bridge.sandbox.types import SandboxAgentBridge
+from ._bridge.types import AgentBridge
+from ._filter import MessageFilter, content_only, last_message, remove_tools
 from ._handoff import handoff
 from ._human.agent import human_cli
 from ._react import react
@@ -22,6 +25,11 @@ __all__ = [
     "handoff",
     "as_tool",
     "as_solver",
+    "agent_bridge",
+    "sandbox_agent_bridge",
+    "AgentBridge",
+    "SandboxAgentBridge",
+    "content_only",
     "last_message",
     "remove_tools",
     "MessageFilter",
