@@ -1,6 +1,8 @@
 from logging import getLogger
 from typing import (
     Callable,
+    Literal,
+    TypedDict,
 )
 
 from pydantic import JsonValue
@@ -45,11 +47,16 @@ logger = getLogger(__name__)
 ATTACHMENT_PROTOCOL = "attachment://"
 
 
+class WalkContext(TypedDict):
+    message_cache: dict[str, ChatMessage]
+    only_core: bool
+
+
 def condense_sample(sample: EvalSample, log_images: bool = True) -> EvalSample:
     """Reduce the storage size of the eval sample.
 
     Reduce size by:
-    1. De-duplciating larger content fields (especially important for images
+    1. De-duplicating larger content fields (especially important for images
        but also for message repeated over and over in the event stream)
     2. Removing base64 encoded images if log_images is True
 
@@ -69,21 +76,27 @@ def condense_sample(sample: EvalSample, log_images: bool = True) -> EvalSample:
     events_fn = events_attachment_fn(attachments, log_images)
     messages_fn = messages_attachment_fn(attachments, log_images)
 
+    context = WalkContext(message_cache={}, only_core=False)
     return sample.model_copy(
         update={
-            "input": walk_input(sample.input, messages_fn),
-            "messages": walk_chat_messages(sample.messages, messages_fn),
-            "events": walk_events(sample.events, events_fn),
+            "input": walk_input(sample.input, messages_fn, context),
+            "messages": walk_chat_messages(sample.messages, messages_fn, context),
+            "events": walk_events(sample.events, events_fn, context),
             "attachments": attachments,
         }
     )
 
 
 def condense_event(
-    event: Event, attachments: dict[str, str], log_images: bool = True
+    event: Event,
+    attachments: dict[str, str],
+    log_images: bool = True,
+    context: WalkContext | None = None,
 ) -> Event:
     event_fn = events_attachment_fn(attachments, log_images)
-    return walk_event(event, event_fn)
+    if context is None:
+        context = WalkContext(message_cache={}, only_core=False)
+    return walk_event(event, event_fn, context)
 
 
 def events_attachment_fn(
@@ -132,7 +145,10 @@ def attachment_fn(attachments: dict[str, str]) -> Callable[[str], str]:
     return create_attachment
 
 
-def resolve_sample_attachments(sample: EvalSample) -> EvalSample:
+def resolve_sample_attachments(
+    sample: EvalSample,
+    resolve_attachments: bool | Literal["full", "core"] = "core",
+) -> EvalSample:
     """Resolve content attachments (typically images) in sample.
 
     Take 'attachment://*` references and resolve them to their
@@ -140,17 +156,20 @@ def resolve_sample_attachments(sample: EvalSample) -> EvalSample:
 
     Args:
        sample (EvalSample): Eval sample with attachments.
+       resolve_attachments: Should attachments be resolved. "core" means only resolving attachments in the core fields.
 
     Returns:
        EvalSample: Sample with attachment content resolved.
     """
+    if resolve_attachments is False:
+        return sample
 
     def content_fn(text: str) -> str:
         # migrate previous flavor of content reference
         CONTENT_PROTOCOL = "tc://"
         if text.startswith(CONTENT_PROTOCOL):
             text = text.replace(CONTENT_PROTOCOL, ATTACHMENT_PROTOCOL, 1)
-        # resovle attachment
+        # resolve attachment
         if text.startswith(ATTACHMENT_PROTOCOL):
             return sample.attachments.get(
                 text.replace(ATTACHMENT_PROTOCOL, "", 1), text
@@ -158,11 +177,15 @@ def resolve_sample_attachments(sample: EvalSample) -> EvalSample:
         else:
             return text
 
+    context = WalkContext(
+        message_cache={},
+        only_core=resolve_attachments == "core",
+    )
     return sample.model_copy(
         update={
-            "input": walk_input(sample.input, content_fn),
-            "messages": walk_chat_messages(sample.messages, content_fn),
-            "events": walk_events(sample.events, content_fn),
+            "input": walk_input(sample.input, content_fn, context),
+            "messages": walk_chat_messages(sample.messages, content_fn, context),
+            "events": walk_events(sample.events, content_fn, context),
             "attachments": {},
         }
     )
@@ -187,89 +210,107 @@ def attachments_content_fn(
     return content_fn
 
 
-def walk_events(events: list[Event], content_fn: Callable[[str], str]) -> list[Event]:
-    return [walk_event(event, content_fn) for event in events]
+def walk_events(
+    events: list[Event], content_fn: Callable[[str], str], context: WalkContext
+) -> list[Event]:
+    return [walk_event(event, content_fn, context) for event in events]
 
 
-def walk_event(event: Event, content_fn: Callable[[str], str]) -> Event:
+def walk_event(
+    event: Event, content_fn: Callable[[str], str], context: WalkContext
+) -> Event:
     if isinstance(event, SampleInitEvent):
-        return walk_sample_init_event(event, content_fn)
+        return walk_sample_init_event(event, content_fn, context)
     elif isinstance(event, ModelEvent):
-        return walk_model_event(event, content_fn)
+        return walk_model_event(event, content_fn, context)
     elif isinstance(event, StateEvent):
-        return walk_state_event(event, content_fn)
+        return walk_state_event(event, content_fn, context)
     elif isinstance(event, StoreEvent):
-        return walk_store_event(event, content_fn)
+        return walk_store_event(event, content_fn, context)
     elif isinstance(event, SubtaskEvent):
-        return walk_subtask_event(event, content_fn)
+        return walk_subtask_event(event, content_fn, context)
     elif isinstance(event, ToolEvent):
-        return walk_tool_event(event, content_fn)
+        return walk_tool_event(event, content_fn, context)
     elif isinstance(event, InfoEvent):
-        return walk_info_event(event, content_fn)
+        return walk_info_event(event, content_fn, context)
     else:
         return event
 
 
 def walk_subtask_event(
-    event: SubtaskEvent, content_fn: Callable[[str], str]
+    event: SubtaskEvent, content_fn: Callable[[str], str], context: WalkContext
 ) -> SubtaskEvent:
-    return event.model_copy(update=dict(events=walk_events(event.events, content_fn)))
+    return event.model_copy(
+        update=dict(events=walk_events(event.events, content_fn, context))
+    )
 
 
-def walk_tool_event(event: ToolEvent, content_fn: Callable[[str], str]) -> ToolEvent:
+def walk_tool_event(
+    event: ToolEvent, content_fn: Callable[[str], str], context: WalkContext
+) -> ToolEvent:
     return event.model_copy(
         update=dict(
-            arguments=walk_json_dict(event.arguments, content_fn),
-            events=walk_events(event.events, content_fn),
+            arguments=walk_json_dict(event.arguments, content_fn, context),
+            events=walk_events(event.events, content_fn, context),
         )
     )
 
 
-def walk_info_event(event: InfoEvent, content_fn: Callable[[str], str]) -> InfoEvent:
-    return event.model_copy(update=dict(data=walk_json_value(event.data, content_fn)))
+def walk_info_event(
+    event: InfoEvent, content_fn: Callable[[str], str], context: WalkContext
+) -> InfoEvent:
+    return event.model_copy(
+        update=dict(data=walk_json_value(event.data, content_fn, context))
+    )
 
 
 def walk_sample_init_event(
-    event: SampleInitEvent, content_fn: Callable[[str], str]
+    event: SampleInitEvent, content_fn: Callable[[str], str], context: WalkContext
 ) -> SampleInitEvent:
     return event.model_copy(
         update=dict(
-            sample=walk_sample(event.sample, content_fn),
-            state=walk_json_value(event.state, content_fn),
+            sample=walk_sample(event.sample, content_fn, context),
+            state=walk_json_value(event.state, content_fn, context),
         )
     )
 
 
-def walk_sample(sample: Sample, content_fn: Callable[[str], str]) -> Sample:
+def walk_sample(
+    sample: Sample, content_fn: Callable[[str], str], context: WalkContext
+) -> Sample:
     if isinstance(sample.input, str):
         return sample.model_copy(
-            update=dict(input=walk_json_value(sample.input, content_fn))
+            update=dict(input=walk_json_value(sample.input, content_fn, context))
         )
     else:
         return sample.model_copy(
-            update=dict(input=walk_chat_messages(sample.input, content_fn))
+            update=dict(input=walk_chat_messages(sample.input, content_fn, context))
         )
 
 
-def walk_model_event(event: ModelEvent, content_fn: Callable[[str], str]) -> ModelEvent:
+def walk_model_event(
+    event: ModelEvent, content_fn: Callable[[str], str], context: WalkContext
+) -> ModelEvent:
     return event.model_copy(
         update=dict(
-            tools=walk_tools(event.tools, content_fn),
-            input=walk_chat_messages(event.input, content_fn),
-            output=walk_model_output(event.output, content_fn),
-            call=walk_model_call(event.call, content_fn),
+            tools=walk_tools(event.tools, content_fn, context),
+            input=walk_chat_messages(event.input, content_fn, context),
+            output=walk_model_output(event.output, content_fn, context),
+            call=walk_model_call(event.call, content_fn, context),
         ),
     )
 
 
 def walk_model_output(
-    output: ModelOutput, content_fn: Callable[[str], str]
+    output: ModelOutput, content_fn: Callable[[str], str], context: WalkContext
 ) -> ModelOutput:
     return output.model_copy(
         update=dict(
             choices=[
                 choice.model_copy(
-                    update=dict(message=walk_chat_message(choice.message, content_fn))
+                    update=dict(
+                        message=walk_chat_message(choice.message, content_fn, context)
+                    )
                 )
                 for choice in output.choices
             ]
@@ -278,34 +319,42 @@ def walk_model_output(
 
 
 def walk_model_call(
-    call: ModelCall | None, content_fn: Callable[[str], str]
+    call: ModelCall | None, content_fn: Callable[[str], str], context: WalkContext
 ) -> ModelCall | None:
+    if context.get("only_core") is True:
+        return call
     if call:
         return ModelCall(
-            request=walk_json_dict(call.request, content_fn),
-            response=walk_json_dict(call.response, content_fn),
+            request=walk_json_dict(call.request, content_fn, context),
+            response=walk_json_dict(call.response, content_fn, context),
             time=call.time,
         )
     else:
         return None
 
 
-def walk_state_event(event: StateEvent, content_fn: Callable[[str], str]) -> StateEvent:
+def walk_state_event(
+    event: StateEvent, content_fn: Callable[[str], str], context: WalkContext
+) -> StateEvent:
     event = event.model_copy(
         update=dict(
             changes=[
-                walk_state_json_change(change, content_fn) for change in event.changes
+                walk_state_json_change(change, content_fn, context)
+                for change in event.changes
             ]
         )
     )
     return event
 
 
-def walk_store_event(event: StoreEvent, content_fn: Callable[[str], str]) -> StoreEvent:
+def walk_store_event(
+    event: StoreEvent, content_fn: Callable[[str], str], context: WalkContext
+) -> StoreEvent:
     event = event.model_copy(
         update=dict(
             changes=[
-                walk_state_json_change(change, content_fn) for change in event.changes
+                walk_state_json_change(change, content_fn, context)
+                for change in event.changes
             ]
         )
     )
@@ -313,30 +362,34 @@ def walk_store_event(event: StoreEvent, content_fn: Callable[[str], str]) -> Sto
 
 
 def walk_state_json_change(
-    change: JsonChange, content_fn: Callable[[str], str]
+    change: JsonChange, content_fn: Callable[[str], str], context: WalkContext
 ) -> JsonChange:
     return change.model_copy(
-        update=dict(value=walk_json_value(change.value, content_fn))
+        update=dict(value=walk_json_value(change.value, content_fn, context))
     )
 
 
-def walk_json_value(value: JsonValue, content_fn: Callable[[str], str]) -> JsonValue:
+def walk_json_value(
+    value: JsonValue, content_fn: Callable[[str], str], context: WalkContext
+) -> JsonValue:
     if isinstance(value, str):
         return content_fn(value)
     elif isinstance(value, list):
-        return [walk_json_value(v, content_fn) for v in value]
+        return [walk_json_value(v, content_fn, context) for v in value]
     elif isinstance(value, dict):
-        return walk_json_dict(value, content_fn)
+        return walk_json_dict(value, content_fn, context)
     else:
         return value
 
 
 def walk_json_dict(
-    value: dict[str, JsonValue], content_fn: Callable[[str], str]
+    value: dict[str, JsonValue],
+    content_fn: Callable[[str], str],
+    context: WalkContext,
 ) -> dict[str, JsonValue]:
     updates: dict[str, JsonValue] = {}
     for k, v in value.items():
-        updates[k] = walk_json_value(v, content_fn)
+        updates[k] = walk_json_value(v, content_fn, context)
     if updates:
         value = value.copy()
         value.update(updates)
@@ -344,42 +397,57 @@ def walk_json_dict(
 
 
 def walk_input(
-    input: str | list[ChatMessage], content_fn: Callable[[str], str]
+    input: str | list[ChatMessage],
+    content_fn: Callable[[str], str],
+    context: WalkContext,
 ) -> str | list[ChatMessage]:
     if isinstance(input, str):
         return input
     else:
-        return walk_chat_messages(input, content_fn)
+        return walk_chat_messages(input, content_fn, context)
 
 
 def walk_chat_messages(
-    messages: list[ChatMessage], content_fn: Callable[[str], str]
+    messages: list[ChatMessage],
+    content_fn: Callable[[str], str],
+    context: WalkContext,
 ) -> list[ChatMessage]:
-    return [walk_chat_message(message, content_fn) for message in messages]
+    return [walk_chat_message(message, content_fn, context) for message in messages]
 
 
 def walk_chat_message(
-    message: ChatMessage, content_fn: Callable[[str], str]
+    message: ChatMessage, content_fn: Callable[[str], str], context: WalkContext
 ) -> ChatMessage:
+    cache = context.get("message_cache")
+    if cache is not None and message.id is not None:
+        hit = cache.get(message.id)
+        if hit is not None and hit == message:
+            return hit
     if isinstance(message.content, str):
-        return message.model_copy(update=dict(content=content_fn(message.content)))
+        res = message.model_copy(update=dict(content=content_fn(message.content)))
     else:
-        return message.model_copy(
+        res = message.model_copy(
             update=dict(
                 tool_calls=[
-                    walk_tool_call(tool_call, content_fn)
+                    walk_tool_call(tool_call, content_fn, context)
                     for tool_call in message.tool_calls
                 ]
                 if isinstance(message, ChatMessageAssistant) and message.tool_calls
                 else None,
                 content=[
-                    walk_content(content, content_fn) for content in message.content
+                    walk_content(content, content_fn, context)
+                    for content in message.content
                 ],
             )
         )
+    if cache is not None and message.id is not None:
+        cache[message.id] = res
+    return res
 
 
-def walk_content(content: Content, content_fn: Callable[[str], str]) -> Content:
+def walk_content(
+    content: Content, content_fn: Callable[[str], str], context: WalkContext
+) -> Content:
     if isinstance(content, ContentText):
         return content.model_copy(update=dict(text=content_fn(content.text)))
     elif isinstance(content, ContentImage):
@@ -393,21 +461,21 @@ def walk_content(content: Content, content_fn: Callable[[str], str]) -> Content:
     elif isinstance(content, ContentToolUse):
         return content.model_copy(
             update=dict(
-                arguments=walk_json_value(content.arguments, content_fn),
-                result=walk_json_value(content.result, content_fn),
+                arguments=walk_json_value(content.arguments, content_fn, context),
+                result=walk_json_value(content.result, content_fn, context),
                 error=content_fn(content.error) if content.error else content.error,
             )
         )
     elif isinstance(content, ContentData):
         return content.model_copy(
-            update=dict(data=walk_json_value(content.data, content_fn))
+            update=dict(data=walk_json_value(content.data, content_fn, context))
         )
     elif isinstance(content, ContentDocument):
         return content.model_copy(update=dict(document=content_fn(content.document)))
 
 
 def walk_tools(
-    tools: list[ToolInfo], content_fn: Callable[[str], str]
+    tools: list[ToolInfo], content_fn: Callable[[str], str], context: WalkContext
 ) -> list[ToolInfo]:
     return [
         tool.model_copy(
@@ -419,11 +487,13 @@ def walk_tools(
     ]
 
 
-def walk_tool_call(tool_call: ToolCall, content_fn: Callable[[str], str]) -> ToolCall:
+def walk_tool_call(
+    tool_call: ToolCall, content_fn: Callable[[str], str], context: WalkContext
+) -> ToolCall:
     return ToolCall(
         id=tool_call.id,
         function=tool_call.function,
-        arguments=walk_json_dict(tool_call.arguments, content_fn),
+        arguments=walk_json_dict(tool_call.arguments, content_fn, context),
         parse_error=tool_call.parse_error,
         view=tool_call.view.model_copy(
             update=dict(
