@@ -22,7 +22,7 @@ def convert_eval_logs(
     to: Literal["eval", "json"],
     output_dir: str,
     overwrite: bool = False,
-    resolve_attachments: bool = False,
+    resolve_attachments: bool | Literal["full", "core"] = False,
     stream: int | bool = False,
 ) -> None:
     """Convert between log file formats.
@@ -118,7 +118,7 @@ async def _stream_convert_file(
     input_file: str,
     output_file: str,
     output_dir: str,
-    resolve_attachments: bool,
+    resolve_attachments: bool | Literal["full", "core"],
     stream: int | Literal[True],
 ) -> None:
     input_recorder = recorder_type_for_location(input_file)
@@ -134,7 +134,7 @@ async def _stream_convert_file(
         async with semaphore:
             sample = await input_recorder.read_log_sample(input_file, sample_id, epoch)
             if resolve_attachments:
-                sample = resolve_sample_attachments(sample)
+                sample = resolve_sample_attachments(sample, resolve_attachments)
             await output_recorder.log_sample(
                 log_header.eval,
                 sample,
