@@ -1,6 +1,6 @@
 from pydantic import BaseModel
 
-from inspect_ai.log._transcript import Event
+from inspect_ai.event._event import Event
 
 
 class SampleEvent(BaseModel):
