@@ -20,6 +20,7 @@ from inspect_ai.event._info import InfoEvent
 from inspect_ai.event._model import ModelEvent
 from inspect_ai.event._store import StoreEvent
 from inspect_ai.log._condense import (
+    WalkContext,
     events_attachment_fn,
     walk_model_call,
 )
@@ -35,6 +36,7 @@ class Transcript:
     """Transcript of events."""
 
     _event_logger: Callable[[Event], None] | None
+    _context: WalkContext
 
     @overload
     def __init__(self) -> None: ...
@@ -44,6 +46,7 @@ class Transcript:
 
     def __init__(self, events: list[Event] | None = None) -> None:
         self._event_logger = None
+        self._context = WalkContext(message_cache={}, only_core=False)
         self._events: list[Event] = events if events is not None else []
         self._attachments: dict[str, str] = {}
 
@@ -90,7 +93,7 @@ class Transcript:
         # condense model event calls immediately to prevent O(N) memory usage
         if isinstance(event, ModelEvent):
             event_fn = events_attachment_fn(self.attachments)
-            event.call = walk_model_call(event.call, event_fn)
+            event.call = walk_model_call(event.call, event_fn, self._context)
 
         self._events.append(event)
 
@@ -101,7 +104,7 @@ class Transcript:
         # condense model event call immediately to prevent O(N) memory usage (call is the only changed fields
         if isinstance(event, ModelEvent):
             event_fn = events_attachment_fn(self.attachments)
-            event.call = walk_model_call(event.call, event_fn)
+            event.call = walk_model_call(event.call, event_fn, self._context)
 
     def _subscribe(self, event_logger: Callable[[Event], None]) -> None:
         self._event_logger = event_logger
