@@ -8,6 +8,7 @@ import httpx
 from openai import (
     DEFAULT_CONNECTION_LIMITS,
     DEFAULT_TIMEOUT,
+    APIConnectionError,
     APIStatusError,
     APITimeoutError,
     OpenAIError,
@@ -678,7 +679,7 @@ def openai_should_retry(ex: BaseException) -> bool:
         return is_retryable_http_status(ex.status_code)
     elif isinstance(ex, OpenAIResponseError):
         return ex.code in ["rate_limit_exceeded", "server_error"]
-    elif isinstance(ex, APITimeoutError):
+    elif isinstance(ex, APIConnectionError | APITimeoutError):
         return True
     else:
         return False
