@@ -80,6 +80,11 @@ class OpenAIAPI(ModelAPI):
             "prompt_cache_key", NOT_GIVEN
         )
 
+        # extract prompt_cache_retention model arg if provided
+        self.prompt_cache_retention: str | NotGiven = model_args.pop(
+            "prompt_cache_retention", NOT_GIVEN
+        )
+
         # extract safety_identifier model arg if provided
         self.safety_identifier: str | NotGiven = model_args.pop(
             "safety_identifier", NOT_GIVEN
@@ -177,6 +182,10 @@ class OpenAIAPI(ModelAPI):
                     os.environ.get("OPENAI_API_VERSION", "2025-03-01-preview"),
                 )
 
+        # set initial reasoning_summaries bit (requires organizational verifification
+        # so we will probe for it on-demand if a request w/ reasoning summaries comes in)
+        self._reasoning_summaries: bool | None = None
+
         # store remaining model_args after extraction
         self.model_args = model_args
         self.initialize()
@@ -345,6 +354,11 @@ class OpenAIAPI(ModelAPI):
         )
         self._resolve_batcher(config, use_responses)
 
+        # if reasoning summaries are unset then try to auto-detect
+        if config.reasoning_summary is None:
+            if not await self.reasoning_summaries():
+                config = config.model_copy(update={"reasoning_summary": "none"})
+
         return await (
             generate_responses(
                 client=self.client,
@@ -357,6 +371,7 @@ class OpenAIAPI(ModelAPI):
                 background=self.background,
                 service_tier=self.service_tier,
                 prompt_cache_key=self.prompt_cache_key,
+                prompt_cache_retention=self.prompt_cache_retention,
                 safety_identifier=self.safety_identifier,
                 responses_store=self.responses_store,
                 model_info=self,
@@ -372,6 +387,7 @@ class OpenAIAPI(ModelAPI):
                 tool_choice=tool_choice,
                 config=config,
                 prompt_cache_key=self.prompt_cache_key,
+                prompt_cache_retention=self.prompt_cache_retention,
                 safety_identifier=self.safety_identifier,
                 openai_api=self,
                 batcher=self._completions_batcher,
@@ -409,6 +425,28 @@ class OpenAIAPI(ModelAPI):
         """Scope for enforcing max_connections (could also use endpoint)."""
         return str(self.api_key)
 
+    async def reasoning_summaries(self) -> bool:
+        # validate that reasoning summaries are supported for this account
+        # (needs to be a 'verified organization'). we do this by making a
+        # simple request with reasoning summaries and if it succeeds we
+        # set the reasoning_summaries bit (we do this once for the lifetime
+        # of the model provider instance)
+        if self._reasoning_summaries is None:
+            reasoning_summaries = False
+            if self.responses_api and self.has_reasoning_options():
+                try:
+                    await self.client.responses.create(
+                        model=self.service_model_name(),
+                        input="Please say 'hello, world'",
+                        reasoning={"effort": "low", "summary": "auto"},
+                    )
+                    reasoning_summaries = True
+                except Exception:
+                    pass
+            self._reasoning_summaries = reasoning_summaries
+
+        return self._reasoning_summaries
+
     def _resolve_batcher(self, config: GenerateConfig, for_responses_api: bool) -> None:
         def _resolve_retry_config() -> ModelRetryConfig:
             return model_retry_config(
