@@ -68,7 +68,7 @@ def anthropic() -> type[ModelAPI]:
 def google() -> type[ModelAPI]:
     FEATURE = "Google API"
     PACKAGE = "google-genai"
-    MIN_VERSION = "1.16.1"
+    MIN_VERSION = "1.51.0"
 
     # verify we have the package
     try:
@@ -139,8 +139,18 @@ def mistral() -> type[ModelAPI]:
 
 @modelapi(name="grok")
 def grok() -> type[ModelAPI]:
-    # validate
-    validate_openai_client("Grok API")
+    FEATURE = "Grok API"
+    PACKAGE = "xai_sdk"
+    MIN_VERSION = "1.3.1"
+
+    # verify we have the package
+    try:
+        import xai_sdk  # type: ignore[import-untyped] # noqa: F401
+    except ImportError:
+        raise pip_dependency_error(FEATURE, [PACKAGE])
+
+    # verify version
+    verify_required_version(FEATURE, PACKAGE, MIN_VERSION)
 
     # in the clear
     from .grok import GrokAPI
@@ -299,7 +309,7 @@ def hf_inference_providers() -> type[ModelAPI]:
 def validate_openai_client(feature: str) -> None:
     FEATURE = feature
     PACKAGE = "openai"
-    MIN_VERSION = "2.0.0"
+    MIN_VERSION = "2.8.0"
 
     # verify we have the package
     try:
