@@ -44,7 +44,6 @@ def completions_agent(tools: bool) -> Agent:
                 model="inspect",
                 messages=await messages_to_openai(state.messages),
                 temperature=0.8,
-                top_p=0.5,
                 stop=["foo"],
                 frequency_penalty=1,
                 presence_penalty=1.5,
@@ -94,6 +93,7 @@ def check_openai_responses_log_json(log_json: str, tools: bool):
     assert r'"max_tool_calls": 5' in log_json
     assert r'"foo": "bar"' in log_json
     assert r'"prompt_cache_key": "42"' in log_json
+    assert r'"prompt_cache_retention": "24h"' in log_json
     assert r'"safety_identifier": "42"' in log_json
     assert r'"truncation": "auto"' in log_json
     if tools:
@@ -162,6 +162,7 @@ def responses_agent(tools: bool) -> Agent:
                 max_tool_calls=5,
                 metadata={"foo": "bar"},
                 prompt_cache_key="42",
+                prompt_cache_retention="24h",
                 safety_identifier="42",
                 truncation="auto",
             )
@@ -234,7 +235,6 @@ def anthropic_agent(tools: bool) -> Agent:
                 model="inspect",
                 max_tokens=4096,
                 temperature=0.8,
-                top_p=0.5,
                 top_k=2,
                 thinking={"type": "enabled", "budget_tokens": 2048}
                 if not tools
@@ -361,7 +361,6 @@ def check_openai_log_json(log_json: str, tools: bool):
     assert r'"presence_penalty": 1.5' in log_json
     assert r'"seed": 42' in log_json
     assert r'"temperature": 0.8' in log_json
-    assert r'"top_p": 0.5' in log_json
     assert r'"n": 3' in log_json
     if not tools:
         assert r'"logprobs": true' in log_json
@@ -417,7 +416,7 @@ def test_bridged_web_search_tool_openai():
 @skip_if_no_anthropic
 def test_bridged_agent_anthropic():
     log_json = eval_bridged_task(
-        "anthropic/claude-sonnet-4-20250514", agent=anthropic_agent(False)
+        "anthropic/claude-sonnet-4-5", agent=anthropic_agent(False)
     )
     check_anthropic_bridge_log_json(log_json, tools=False)
 
@@ -425,7 +424,7 @@ def test_bridged_agent_anthropic():
 @skip_if_no_anthropic
 def test_bridged_agent_anthropic_tools():
     log_json = eval_bridged_task(
-        "anthropic/claude-sonnet-4-20250514", agent=anthropic_agent(True)
+        "anthropic/claude-sonnet-4-5", agent=anthropic_agent(True)
     )
     check_anthropic_bridge_log_json(log_json, tools=True)
 
@@ -434,7 +433,7 @@ def test_bridged_agent_anthropic_tools():
 def test_bridged_web_search_tool_anthropic():
     log = eval(
         web_search_task(anthropic_web_search_agent()),
-        model="anthropic/claude-sonnet-4-20250514",
+        model="anthropic/claude-sonnet-4-5",
     )[0]
     log_json = log.model_dump_json(exclude_none=True, indent=2)
     assert '"max_uses": 5' in log_json
@@ -446,7 +445,7 @@ def test_bridged_web_search_tool_anthropic():
 def test_bridged_web_search_tool_openai_to_anthropic():
     log = eval(
         web_search_task(responses_web_search_agent()),
-        model="anthropic/claude-sonnet-4-20250514",
+        model="anthropic/claude-sonnet-4-5",
     )[0]
     check_web_search_tool_use(log, "web_search")
 
@@ -483,9 +482,8 @@ def check_web_search_tool_use(log: EvalLog, tool_name: str):
 
 
 def check_anthropic_log_json(log_json: str):
-    assert r'"model": "anthropic/claude-sonnet-4-20250514"' in log_json
+    assert r'"model": "anthropic/claude-sonnet-4-5"' in log_json
     assert r'"temperature": 0.8' in log_json
-    assert r'"top_p": 0.5' in log_json
     assert dedent("""
     "stop_sequences": [
       "foo"
@@ -494,10 +492,9 @@ def check_anthropic_log_json(log_json: str):
 
 
 def check_anthropic_bridge_log_json(log_json: str, tools: bool):
-    assert r'"model": "anthropic/claude-sonnet-4-20250514"' in log_json
+    assert r'"model": "anthropic/claude-sonnet-4-5"' in log_json
     assert r'"max_tokens": 4096' in log_json
     assert r'"temperature": 0.8' in log_json
-    assert r'"top_p": 0.5' in log_json
     assert r'"top_k": 2' in log_json
     if tools:
         assert r'"name": "get_weather"' in log_json
@@ -509,7 +506,7 @@ def check_anthropic_bridge_log_json(log_json: str, tools: bool):
 @skip_if_no_openai
 def test_anthropic_bridged_agent():
     log_json = eval_bridged_task(
-        "anthropic/claude-sonnet-4-20250514", agent=completions_agent(False)
+        "anthropic/claude-sonnet-4-5", agent=completions_agent(False)
     )
     check_anthropic_log_json(log_json)
 
@@ -520,7 +517,7 @@ def test_bridged_agent_context():
     logs = eval(
         [bridged_task(agent=completions_agent(False)), openai_api_task()],
         max_tasks=2,
-        model="anthropic/claude-sonnet-4-20250514",
+        model="anthropic/claude-sonnet-4-5",
     )
     for log in logs:
         assert log.status == "success"
