@@ -8,14 +8,12 @@ from inspect_ai.model import (
 )
 
 
-@pytest.mark.anyio
+@pytest.mark.asyncio
 @skip_if_no_grok
 async def test_grok_api() -> None:
     model = get_model(
         "grok/grok-3-mini",
         config=GenerateConfig(
-            stop_seqs=None,
-            seed=None,
             temperature=0.0,
             top_p=1.0,
         ),
