@@ -3,15 +3,16 @@ from test_helpers.utils import skip_if_no_google
 from inspect_ai import Task, eval
 from inspect_ai._util.content import ContentReasoning
 from inspect_ai.dataset import Sample
+from inspect_ai.log._log import EvalLog
 
 
 @skip_if_no_google
-def test_google_reasoning():
+def test_google_reasoning_tokens():
     # run eval w/ reasoning tokens
     task = Task(dataset=[Sample(input="Solve 3*x^3-5*x=1")])
     log = eval(
         task,
-        model="google/gemini-2.5-flash-preview-05-20",
+        model="google/gemini-2.5-flash",
         reasoning_tokens=1024,
     )[0]
     assert log.status == "success"
@@ -19,9 +20,33 @@ def test_google_reasoning():
     # confirm thinking budget was set and reasoning was done
     log_json = log.model_dump_json(indent=2)
     assert '"thinkingBudget": 1024' in log_json
+
+    check_for_reasoning(log)
+
+
+@skip_if_no_google
+def test_google_reasoning_effort():
+    # run eval w/ reasoning tokens
+    task = Task(dataset=[Sample(input="Solve 3*x^3-5*x=1")])
+    log = eval(
+        task,
+        model="google/gemini-3-pro-preview",
+        reasoning_effort="low",
+    )[0]
+    assert log.status == "success"
+
+    # confirm thinking budget was set and reasoning was done
+    log_json = log.model_dump_json(indent=2)
+    assert '"thinkingLevel": "LOW"' in log_json
+
+    check_for_reasoning(log)
+
+
+def check_for_reasoning(log: EvalLog) -> None:
     assert log.samples
     output = log.samples[0].output
-    assert output.usage.reasoning_tokens > 0
+    assert output.usage
+    assert output.usage.reasoning_tokens
 
     # confirm we captured the reasoning content block
     content = output.message.content
